@@ -134,9 +134,9 @@ has 'TreeConfig', is => 'ro', isa => 'ArrayRef[HashRef]', lazy => 1, default =>
       # place (note this probably needs to be fixed in there for exactly this reason)
       my $cust_merged = clone( Catalyst::Utils::merge_hashes($cust_def_config,$cust_config) );
       
-      my $table = $Source->schema->class($Source->source_name)->table;
-      $table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
-      my $module_name = lc(join('_',$model,$table));
+      #my $table = $Source->schema->class($Source->source_name)->table;
+      #$table = (split(/\./,$table,2))[1] || $table; #<-- get 'table' for both 'db.table' and 'table' format
+      my $module_name = lc(join('_',$model,$source));
       $module_name =~ s/\:\:/_/g;
       $self->apply_init_modules( $module_name => {
         class => $self->table_class,
